/**
 * GA Service
 *      Any class which handles all of the domain specific functions of the GA process
 */
export interface GAService<T> {
    /**
     * The main method of Evolution - creating children
     * by mating two citizens (of type T)
     */
    mate(a: T, b: T): T;
    /**
     * Mutate a citizen (of type T) by a specific mutationRate
     */
    mutate(citizen: T, mutationRate?: number): T;
    /**
     * The fitness function, what is the fitness of a given citizen (of type T)
     */
    fitness: (citizen: T) => number;
}
/**
    The GA class provides the evolutionary framework for
    evolving citizens to reach a higher and higher level
    of fitness.
 */
export declare class GA<T> {
    private ga;
    constructor(ga: GAService<T>);
    generation: number;
    mutationRate: number;
    survivalRate: number;
    private _population;
    population: Array<T>;
    readonly fitness: number;
    readonly fittest: T;
    reset(): void;
    sort(): void;
    evolve(): void;
}
